Module functions

Module functions 

Modules

add_int_64_format
add_s
add_value
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:796:add_value
addfield
Node: cxx:Function:Luau.VM:VM/src/ltablib.cpp:230:addfield
addquoted
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:884:addquoted
adjustasize
andaux
append
arrayindex
arrayornewkey
atomic
aux_upvalue
aux_upvalue — resolve the n-th upvalue slot in a function TValue. C++ source: VM/src/lapi.cpp:1487
auxgetinfo
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:106:auxgetinfo
auxopen
auxresume
auxresumecont
auxwrapcont
auxwrapfinish
Node: cxx:Function:Luau.VM:VM/src/lcorolib.cpp:144:auxwrapfinish Source: VM/src/lcorolib.cpp:144-157 (hand-ported)
auxwrapy
b_and
b_arshift
b_countlz
b_countrz
b_extract
b_lrot
b_lshift
b_not
b_or
b_replace
b_rot
b_rrot
b_rshift
b_shift
b_swap
b_test
b_xor
buffer_copy
buffer_create
buffer_fill
buffer_fromstring
buffer_len
buffer_readbits
buffer_readfp
buffer_readinteger
buffer_readlong
buffer_readstring
buffer_swapbe
buffer_tostring
buffer_writebits
buffer_writefp
buffer_writeinteger
buffer_writelong
buffer_writestring
buffutfchar
byteoffset
call_bin_tm
call_order_tm
call_t_mres
call_tm
callerrfunc
Node: cxx:Function:Luau.VM:VM/src/ldo.cpp:718:callerrfunc Source: VM/src/ldo.cpp (ldo.cpp:718-727, hand-ported)
capture_to_close
check_capture
class_classof
class_isinstance
classend
cleanupcistack
clearstack
cleartable
clearupvals
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:858:clearupvals Source: VM/src/lgc.cpp (lgc.cpp:858-890, hand-ported)
clock_period
clock_timestamp
close_state
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:92:close_state Source: VM/src/lstate.cpp:92-113 (hand-ported)
coclose
Node: cxx:Function:Luau.VM:VM/src/lcorolib.cpp:219:coclose
cocreate
codepoint
computesizes
copywithendian
coresumecont
coresumefinish
coresumey
correctstack
corunning
costatus
Node: cxx:Function:Luau.VM:VM/src/lcorolib.cpp:14:costatus
countint
cowrap
coyield
coyieldable
createmetatable_lstrlib
createmetatable_lveclib
currentline
currentpc
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:17:currentpc Source: VM/src/ldebug.cpp Graph edges:
currfuncname
db_info
db_traceback
deletegco
digit
dumpbuffer
dumpclass
dumpclosure
dumpgco
dumpobj
dumpobject
dumpproto
dumpref
dumprefs
dumpstring
dumpstringdata
dumptable
dumpthread
dumpudata
dumpupval
end_capture
enumbuffer
enumclass
enumclosure
enumedge
enumedges
enumgco
enumnode
enumobj
enumobject
enumproto
enumstring
enumtable
enumthread
enumtopointer
enumudata
enumupval
extendstrbuf
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:449:extendstrbuf
f_call
f_ccall
f_luaopen
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:59:f_luaopen Source: VM/src/lstate.cpp:59-70 (hand-ported)
fieldargs
findindex
finish_gc_cycle_metrics
foreach
foreachi
freeblock
freeclasspage
Node: cxx:Function:Luau.VM:VM/src/lmem.cpp:322:freeclasspage Source: VM/src/lmem.cpp:322-331 (hand-ported)
freegcoblock
freeobj
freepage
freestack
gcstep
get_comp_tm
getboolfield
getcoverage
getcurrenv
getdetails
getfield
getfreepos
getfunc
Node: cxx:Function:Luau.VM:VM/src/lbaselib.cpp:108:getfunc
getfuncname
getheaptrigger
getheaptriggererroroffset
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:1100:getheaptriggererroroffset Source: VM/src/lgc.cpp:1100-1130 (hand-ported)
getluaproto
getmaxline
getn
getnextbuffersize
getnextline
getnum
getnumlimit
getoption
gettablemode
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:311:gettablemode Source: VM/src/lgc.cpp:311-319 (hand-ported)
getthread
gmatch
gmatch_aux
gmtime_r
gnext_ltable
gnext_ltable_alt_b
gnext_ltable_alt_c
hashint
hashnum
hashpointer
hashvec
index_2_addr
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:99:index2addr Source: VM/src/lapi.cpp:99-118 (hand-ported)
initheader
install_lua_exception_panic_hook
Silence the default panic-hook output for the VM’s longjmp-emulation unwinds.
int_64_add
int_64_arshift
int_64_band
int_64_bnot
int_64_bor
int_64_bswap
int_64_btest
int_64_bxor
int_64_clamp
int_64_countlz
int_64_countrz
int_64_create
int_64_div
int_64_extract
int_64_fromstring
int_64_ge
int_64_gt
int_64_idiv
int_64_le
int_64_lrotate
int_64_lshift
int_64_lt
int_64_max
int_64_min
int_64_mod
int_64_mul
int_64_neg
int_64_rem
int_64_replace
int_64_rrotate
int_64_rshift
int_64_sub
int_64_tonumber
int_64_udiv
int_64_uge
int_64_ugt
int_64_ule
int_64_ult
int_64_urem
interrupt_thread
isobjcleared
Generated skeleton item. Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:608:isobjcleared Source: VM/src/lgc.cpp Graph edges:
iter_aux
iter_codes
l_alloc
libsize
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:297:libsize Source: VM/src/laux.cpp:297-302 (hand-ported)
lmemfind
loadsafe
localtime_r
lua_a_pushclass
luaA_pushclass — push a LuauClass* value onto the Lua stack. C++ source: VM/src/lapi.cpp:133
lua_a_pushvalue
lua_a_toobject
lua_absindex
lua_b_assert
lua_b_error
Node: cxx:Function:Luau.VM:VM/src/lbaselib.cpp:48:luaB_error Source: VM/src/lbaselib.cpp:48-59 (hand-ported)
lua_b_freebuffer
lua_b_gcinfo
lua_b_getfenv
lua_b_getmetatable
lua_b_inext
lua_b_ipairs
lua_b_newbuffer
lua_b_newproxy
lua_b_next
lua_b_pairs
lua_b_pcallcont
lua_b_pcallrun
lua_b_pcally
Node: cxx:Function:Luau.VM:VM/src/lbaselib.cpp:293:luaB_pcally Source: VM/src/lbaselib.cpp:293-312 (hand-ported)
lua_b_print
lua_b_rawequal
lua_b_rawget
lua_b_rawlen
lua_b_rawset
lua_b_select
lua_b_setfenv
lua_b_setmetatable
Node: cxx:Function:Luau.VM:VM/src/lbaselib.cpp:75:luaB_setmetatable Source: VM/src/lbaselib.cpp:75-85 (hand-ported)
lua_b_tonumber
lua_b_tostring
lua_b_type
lua_b_typeof
lua_b_xpcallcont
lua_b_xpcallerr
lua_b_xpcally
lua_break
lua_breakpoint
lua_c_allocationrate
lua_c_barrierback
lua_c_barrierf
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:1284:lua_c_barrierf Source: VM/src/lgc.cpp (lgc.cpp:1284-1294, hand-ported)
lua_c_barriertable
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:1296:lua_c_barriertable Source: VM/src/lgc.cpp (lgc.cpp:1296-1314, hand-ported)
lua_c_dump
lua_c_enumheap
lua_c_freeall
lua_c_fullgc
lua_c_statename
lua_c_step
lua_c_upvalclosed
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:1327:lua_c_upvalclosed Source: VM/src/lgc.cpp (lgc.cpp:1327-1347, hand-ported)
lua_c_validate
lua_call
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:1082:lua_call Source: VM/src/lapi.cpp:1082-1092 (hand-ported)
lua_callbacks
lua_checkstack
lua_cleartable
lua_clock
lua_clonefunction
lua_clonetable
lua_close
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:292:lua_close Source: VM/src/lstate.cpp:292-297 (hand-ported)
lua_concat
lua_costatus
lua_cpcall
lua_createtable
lua_d_call
lua_d_callint
lua_d_callny
lua_d_check_cstack
lua_d_grow_ci
lua_d_growstack
lua_d_pcall
Node: cxx:Function:Luau.VM:VM/src/ldo.cpp:729:lua_d_pcall Source: VM/src/ldo.cpp (ldo.cpp:729-795, hand-ported)
lua_d_performcally
lua_d_rawrunprotected_ldo
Node: cxx:Function:Luau.VM:VM/src/ldo.cpp:124:lua_d_rawrunprotected Source: VM/src/ldo.cpp:124-159 (hand-ported; C++-exceptions build flavor — luaD_throw is panic_any(lua_exception), this is the matching catch_unwind boundary; see translation/design-cards/lvmexecute.md)
lua_d_rawrunprotected_ldo_alt_b
lua_d_realloc_ci
lua_d_reallocstack
lua_d_seterrorobj
lua_d_throw_ldo
Node: cxx:Function:Luau.VM:VM/src/ldo.cpp:162:lua_d_throw Source: VM/src/ldo.cpp (ldo.cpp:162-165, hand-ported; C++-exceptions build flavor, matching the catch_unwind-based luaD_rawrunprotected)
lua_d_throw_ldo_alt_b
Node: cxx:Function:Luau.VM:VM/src/ldo.cpp:64:lua_d_throw Source: VM/src/ldo.cpp (ldo.cpp:64-77 is the LUA_USE_LONGJMP flavor; this build uses the C++-exceptions flavor — one canonical Rust implementation)
lua_debugtrace
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:630:lua_debugtrace Source: VM/src/ldebug.cpp:630-677 (hand-ported)
lua_e_freethread
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:130:luaE_freethread Source: VM/src/lstate.cpp:130-138 (hand-ported)
lua_e_newthread
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:116:luaE_newthread Source: VM/src/lstate.cpp:116-128 (hand-ported)
lua_encodepointer
lua_equal
lua_error
lua_f_close
lua_f_closeupval
Node: cxx:Function:Luau.VM:VM/src/lfunc.cpp:156:lua_f_closeupval Source: VM/src/lfunc.cpp (lfunc.cpp:156-169, hand-ported)
lua_f_findlocal
lua_f_findupval
lua_f_freeclosure
lua_f_freeproto
lua_f_freeupval
lua_f_getlocal
lua_f_new_cclosure
lua_f_new_lclosure
lua_f_newproto
lua_f_recordhit
luaF_recordhit — record a call-target hit in the caller’s feedback vector. C++ source: VM/src/lfunc.cpp:225
lua_g_aritherror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:264:luaG_aritherror Source: VM/src/ldebug.cpp:264-275 (hand-ported; luaT_eventname[op] is read from g->tmname[op], built from the same string table)
lua_g_breakpoint
lua_g_concaterror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:256:luaG_concaterror Source: VM/src/ldebug.cpp:256-262 (hand-ported)
lua_g_forerror_l
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:249:luaG_forerrorL Source: VM/src/ldebug.cpp:249-254 (hand-ported)
lua_g_getline
lua_g_hasnative
lua_g_indexerror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:286:luaG_indexerror Source: VM/src/ldebug.cpp:286-296 (hand-ported)
lua_g_isnative
lua_g_methoderror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:306:luaG_methoderror Source: VM/src/ldebug.cpp:306-311 (hand-ported)
lua_g_missingmembererror
lua_g_onbreak
luaG_onbreak — returns true when the current instruction at the top call frame is LOP_BREAK. C++ source: VM/src/ldebug.cpp:405
lua_g_ordererror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:277:luaG_ordererror Source: VM/src/ldebug.cpp:277-284 (hand-ported)
lua_g_pusherror
lua_g_readonlyerror
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:313:luaG_readonlyerror Source: VM/src/ldebug.cpp:313-316 (hand-ported)
lua_g_runerror_l
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:335:luaG_runerrorL Source: VM/src/ldebug.cpp:335-347 (hand-ported; C varargs follow the project convention of core::fmt::Arguments with the C fmt string unused)
lua_g_typeerror_l
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:242:luaG_typeerrorL Source: VM/src/ldebug.cpp:242-247 (hand-ported)
lua_gc
lua_getallocf
lua_getargument
lua_getcounters
lua_getcoverage
lua_getfenv
lua_getfield
lua_getinfo
Node: cxx:Function:Luau.VM:VM/src/ldebug.cpp:185:lua_getinfo
lua_getlightuserdataname
lua_getlocal
lua_getmetatable
lua_getreadonly
lua_gettable
lua_getthreaddata
lua_gettop
lua_getupvalue
lua_getuserdatadtor
lua_getuserdatametatable
lua_h_clear
lua_h_clone
lua_h_free
lua_h_get
lua_h_getn
lua_h_getnum
lua_h_getp
lua_h_getstr
Node: cxx:Function:Luau.VM:VM/src/ltable.cpp:657:lua_h_getstr Source: VM/src/ltable.cpp (ltable.cpp:657-669, hand-ported)
lua_h_new
lua_h_newkey
lua_h_next
lua_h_resizearray
lua_h_resizehash
lua_h_set
lua_h_setnum
lua_h_setp
lua_h_setstr
lua_insert
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:272:lua_insert Source: VM/src/lapi.cpp:272-280 (hand-ported)
lua_is_lfunction
lua_iscfunction
lua_isnumber
lua_isstring
lua_isthreadreset
lua_isuserdata
lua_isyieldable
lua_l_addchar
luaL_addchar (VM/include/lualib.h macro) — append one byte to a luaL_Strbuf, growing it first if the inline/current buffer is full.
lua_l_addlstring
lua_l_addstring
luaL_addstring (VM/include/lualib.h macro) — append a NUL-terminated C string to a luaL_Strbuf via luaL_addlstring with strlen(s).
lua_l_addvalue
lua_l_addvalueany
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:529:luaL_addvalueany Source: VM/src/laux.cpp:529-582 (hand-ported)
lua_l_argerror_l
lua_l_buffinit
lua_l_buffinitsize
lua_l_callmeta
lua_l_callyieldable
lua_l_checkany
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:159:luaL_checkany Source: VM/src/laux.cpp:159-163 (hand-ported)
lua_l_checkboolean
lua_l_checkbuffer
lua_l_checkinteger
lua_l_checkinteger_64
lua_l_checklstring
lua_l_checknumber
lua_l_checkoption
lua_l_checkstack
lua_l_checktype
lua_l_checkudata
lua_l_checkunsigned
lua_l_checkvector
lua_l_error_l
lua_l_findtable
lua_l_getmetafield
lua_l_newmetatable
lua_l_newstate
lua_l_openlibs
Node: cxx:Function:Luau.VM:VM/src/linit.cpp:42:luaL_openlibs Source: VM/src/linit.cpp:42-60 (hand-ported)
lua_l_optboolean
lua_l_optinteger
lua_l_optinteger_64
lua_l_optlstring
lua_l_optnumber
lua_l_optunsigned
lua_l_optvector
lua_l_prepbuffsize
lua_l_pushresult
lua_l_pushresultsize
lua_l_register
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:304:luaL_register Source: VM/src/laux.cpp:304-327 (hand-ported)
lua_l_sandbox
lua_l_sandboxthread
lua_l_tolstring
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:616:luaL_tolstring Source: VM/src/laux.cpp:616-679 (hand-ported)
lua_l_traceback
lua_l_typeerror_l
lua_l_typename
lua_l_where
Node: cxx:Function:Luau.VM:VM/src/laux.cpp:71:luaL_where Source: VM/src/laux.cpp:71-83 (hand-ported)
lua_lessthan
lua_lightuserdatatag
lua_m_free
lua_m_freearray
lua_m_freegco
lua_m_getnextpage
lua_m_getpageinfo
lua_m_getpagewalkinfo
lua_m_new
lua_m_newgco
lua_m_realloc
Node: cxx:Function:Luau.VM:VM/src/lmem.cpp:599:luaM_realloc_ Source: VM/src/lmem.cpp:599-640 (hand-fixed: the translated version invented a power-of-2 size-class scheme that disagreed with the real progressive table in sizeclass!, so realloc’d blocks were freed under the wrong class and tripped the blockSize assert in freeblock)
lua_m_toobig
Node: cxx:Function:Luau.VM:VM/src/lmem.cpp:wrapper:luaM_toobig Source: VM/src/lmem.cpp (hand-ported)
lua_m_visitgco
lua_m_visitpage
lua_mainthread
lua_namecallatom
lua_newbuffer
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:1477:lua_newbuffer
lua_newstate
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:184:lua_newstate Source: VM/src/lstate.cpp:184-290 (hand-ported)
lua_newthread
lua_newuserdatadtor
lua_newuserdatatagged
lua_newuserdatataggedwithmetatable
lua_next
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:1350:lua_next Source: VM/src/lapi.cpp:1350-1363 (hand-ported)
lua_o_chunkid
lua_o_log_2
lua_o_pushfstring
lua_o_pushvfstring
lua_o_rawequal_key
lua_o_rawequal_obj
lua_o_str_2_d
lua_o_str_2_l
lua_o_utf_8_esc
lua_objlen
lua_pcall
lua_pushboolean
lua_pushcclosurek
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:742:lua_pushcclosurek Source: VM/src/lapi.cpp:742-760 (hand-ported)
lua_pushfstring_l
lua_pushinteger
lua_pushinteger_64
lua_pushlightuserdatatagged
lua_pushlstring
lua_pushnil
lua_pushnumber
lua_pushstring
lua_pushthread
lua_pushunsigned
lua_pushvalue
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:310:lua_pushvalue Source: VM/src/lapi.cpp:310-316 (hand-ported)
lua_pushvector_lapi
lua_pushvector_lapi_alt_b
lua_pushvfstring
lua_r_addclassmember
lua_r_createobject
lua_r_freeclass
lua_r_freeobject
lua_r_newclass
lua_rawcheckstack
lua_rawequal
lua_rawget
lua_rawgetfield
lua_rawgeti
lua_rawgetptagged
lua_rawiter
lua_rawset
lua_rawsetfield
lua_rawseti
lua_rawsetptagged
lua_ref
lua_registeruserdatadirectaccess
lua_registeruserdatadirectfieldget
lua_remove
lua_replace
lua_resetthread
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:148:lua_resetthread Source: VM/src/lstate.cpp:148-180 (hand-ported)
lua_resume
lua_resumeerror
lua_s_buffinish
lua_s_bufstart
lua_s_free
lua_s_hash
lua_s_newlstr
lua_s_resize
lua_setfenv
lua_setfield
lua_setlightuserdataname
lua_setlocal
lua_setmemcat
lua_setmetatable
lua_setreadonly
lua_setsafeenv
lua_settable
lua_setthreaddata
lua_settop
lua_setupvalue
lua_setuserdatadtor
lua_setuserdatametatable
lua_setuserdatametatable — pop a table from the stack and register it as the metatable for userdata of type tag. C++ source: VM/src/lapi.cpp:1616
lua_setuserdatatag
lua_singlestep
lua_stackdepth
lua_status
lua_t_gettm
lua_t_gettmbyobj
lua_t_init
lua_t_objtypename
lua_t_objtypenamestr
lua_toboolean
lua_tobuffer
lua_tocfunction
lua_tointeger_64
lua_tointegerx
lua_tolightuserdata
lua_tolightuserdatatagged
lua_tolstring
lua_tolstringatom
lua_tonumberx
lua_topointer
lua_tostringatom
lua_totalbytes
lua_tothread
lua_tounsignedx
lua_touserdata
lua_touserdatatagged
lua_tovector
lua_type
lua_typename
lua_u_freeudata
lua_u_newudata
lua_unref
lua_userdatadirectfield_setboolean
lua_userdatadirectfield_setinteger_64
lua_userdatadirectfield_setnil
lua_userdatadirectfield_setnumber
lua_userdatadirectfield_setvector_lapi
lua_userdatadirectfield_setvector_lapi_alt_b
lua_userdatatag
lua_v_call_tm
lua_v_concat
Node: cxx:Function:Luau.VM:VM/src/lvmutils.cpp:399:luaV_concat Source: VM/src/lvmutils.cpp:399-461 (hand-ported)
lua_v_doarithimpl
lua_v_dolen
lua_v_equalval
lua_v_getimport
lua_v_gettable
Node: cxx:Function:Luau.VM:VM/src/lvmutils.cpp:102:luaV_gettable Source: VM/src/lvmutils.cpp:102-180 (hand-ported)
lua_v_lessequal
lua_v_lessthan
lua_v_prepare_forn
lua_v_settable
Node: cxx:Function:Luau.VM:VM/src/lvmutils.cpp:182:luaV_settable Source: VM/src/lvmutils.cpp:182-240 (hand-ported)
lua_v_strcmp
lua_v_tonumber
lua_v_tostring
lua_v_tovector
lua_v_tryfunc_tm
lua_xmove
lua_xpush
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:206:lua_xpush Source: VM/src/lapi.cpp:206-212 (hand-ported)
lua_yield
luai_int_2_str
luai_lerpf
luai_num_2_str
luai_numidiv
luai_nummod
luai_veceq
luai_vecisnan
luaopen_base
Node: cxx:Function:Luau.VM:VM/src/lbaselib.cpp:467:luaopen_base Source: VM/src/lbaselib.cpp:438-489 (hand-ported)
luaopen_bit_32
luaopen_buffer
luaopen_class
luaopen_coroutine
luaopen_debug
luaopen_integer
luaopen_math
Node: cxx:Function:Luau.VM:VM/src/lmathlib.cpp:517:luaopen_math Source: VM/src/lmathlib.cpp:473-541 (hand-ported)
luaopen_os
luaopen_string
luaopen_table
Node: cxx:Function:Luau.VM:VM/src/ltablib.cpp:619:luaopen_table Source: VM/src/ltablib.cpp:596-628 (hand-ported)
luaopen_utf_8
luaopen_vector
Node: cxx:Function:Luau.VM:VM/src/lveclib.cpp:341:luaopen_vector Source: VM/src/lveclib.cpp:301-359 (hand-ported)
luau_callhook
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:147:luau_callhook Source: VM/src/lvmexecute.cpp:147-200 (hand-ported)
luau_execute
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3716:luau_execute Source: VM/src/lvmexecute.cpp:228-3722 (hand-port in progress; design card at translation/design-cards/lvmexecute.md)
luau_f_abs
luau_f_acos
luau_f_arshift
luau_f_asin
luau_f_assert
luau_f_atan
luau_f_atan_2
luau_f_band
luau_f_bnot
luau_f_bor
luau_f_btest
luau_f_bufferreadlong
luau_f_bufferwritelong
luau_f_bxor
luau_f_byte
luau_f_byteswap
luau_f_ceil
luau_f_ceil_sse_41
luau_f_char
luau_f_clamp
luau_f_cos
luau_f_cosh
luau_f_countlz
luau_f_countrz
luau_f_deg
luau_f_exp
luau_f_extract
luau_f_extractk
luau_f_floor
luau_f_floor_sse_41
luau_f_fmod
luau_f_frexp
luau_f_getmetatable
luau_f_integeradd
luau_f_integerarshift
luau_f_integerband
luau_f_integerbnot
luau_f_integerbor
luau_f_integerbswap
luau_f_integerbtest
luau_f_integerbxor
luau_f_integerclamp
luau_f_integercountlz
luau_f_integercountrz
luau_f_integercreate
luau_f_integerdiv
luau_f_integerextract
luau_f_integerge
luau_f_integergt
luau_f_integeridiv
luau_f_integerle
luau_f_integerlrotate
luau_f_integerlshift
luau_f_integerlt
luau_f_integermax
luau_f_integermin
luau_f_integermod
luau_f_integermul
luau_f_integerneg
luau_f_integerrem
luau_f_integerrrotate
luau_f_integerrshift
luau_f_integersub
luau_f_integertonumber
luau_f_integerudiv
luau_f_integeruge
luau_f_integerugt
luau_f_integerule
luau_f_integerult
luau_f_integerurem
luau_f_isfinite
luau_f_isinf
luau_f_isnan
luau_f_ldexp
luau_f_len
luau_f_lerp
luau_f_log
luau_f_log_10
luau_f_lrotate
luau_f_lshift
luau_f_max
luau_f_min
luau_f_missing
luau_f_modf
luau_f_pow
luau_f_rad
luau_f_rawequal
luau_f_rawget
luau_f_rawlen
luau_f_rawset
luau_f_readfp
luau_f_readinteger
luau_f_replace
luau_f_round
luau_f_round_sse_41
luau_f_rrotate
luau_f_rshift
luau_f_select
luau_f_setmetatable
luau_f_sign
luau_f_sin
luau_f_sinh
luau_f_sqrt
luau_f_sub
luau_f_tan
luau_f_tanh
luau_f_tinsert
luau_f_tonumber
luau_f_tostring
luau_f_tunpack
luau_f_type
Generated skeleton item. Node: cxx:Function:Luau.VM:VM/src/lbuiltins.cpp:785:luau_f_type Source: VM/src/lbuiltins.cpp Graph edges:
luau_f_typeof
luau_f_vector
luau_f_vectorabs
luau_f_vectorceil
luau_f_vectorclamp
luau_f_vectorcross
luau_f_vectordot
luau_f_vectorfloor
luau_f_vectorlerp
luau_f_vectormagnitude
luau_f_vectormax
luau_f_vectormin
luau_f_vectornormalize
luau_f_vectorsign
luau_f_writefp
luau_f_writeinteger
luau_finishop
luau_hassse_41
luau_load
luau_poscall
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3843:luau_poscall Source: VM/src/lvmexecute.cpp:3843-3872 (hand-ported)
luau_precall
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3757:luau_precall Source: VM/src/lvmexecute.cpp:3757-3841 (hand-ported)
luau_setupcci
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:206:luau_setupcci
luau_skipstep
luaui_clampf
luaui_signf
mainposition
markmt
markroot
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:805:markroot Source: VM/src/lgc.cpp (lgc.cpp:805-837, hand-ported)
match
match_capture
match_class
matchbalance
matchbracketclass
math_abs
math_acos
math_asin
math_atan
math_atan_2
math_ceil
math_clamp
math_cos
math_cosh
math_deg
math_exp
math_floor
math_fmod
math_frexp
math_isfinite
math_isinf
math_isnan
math_ldexp
math_lerp
math_log
math_log_10
math_map
math_max
math_min
math_modf
math_noise
math_pow
math_rad
math_random
Node: cxx:Function:Luau.VM:VM/src/lmathlib.cpp:234:math_random
math_randomseed
math_round
math_sign
math_sin
math_sinh
math_sqrt
math_tan
math_tanh
max_expand
maxn
min_expand
moveelements
mul_128
mul_192_hi
newblock
newclasspage
newgcoblock
newkey
newlstr
newpage
nospecials
numusearray
numusehash
os_clock
os_date
Node: cxx:Function:Luau.VM:VM/src/loslib.cpp:112:os_date
os_difftime
os_time
os_timegm
packint
pcg_32_random
pcg_32_seed
performcall
perlin
perlin_fade
perlin_grad
perlin_lerp
posrelat
preinit_state
prepstate
printexp
printspecial
printunsignedrev
propagateall
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:592:propagateall Source: VM/src/lgc.cpp (lgc.cpp:592-600, hand-ported)
propagatemark
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:504:propagatemark Source: VM/src/lgc.cpp (lgc.cpp:504-590, hand-ported)
pseudo_2_addr
Node: cxx:Function:Luau.VM:VM/src/lapi.cpp:73:pseudo2addr Source: VM/src/lapi.cpp:65-97 (hand-ported; includes the file-static getcurrenv helper inlined here since it was never a graph node)
push_captures
push_onecapture
pusherror
read
read_string
read_var_int
read_var_int_64
reallymarkobject
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:239:reallymarkobject Source: VM/src/lgc.cpp (lgc.cpp:239-309, hand-ported)
record_gc_delta_time
record_gc_state_step
rehash
remap_userdata_types
remarkupvals
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:839:remarkupvals Source: VM/src/lgc.cpp (lgc.cpp:839-856, hand-ported)
removeentry
reprepstate
resize
resolve_import_safe
restore_stack_limit
resume
resume_continue
resume_error
resume_findhandler
resume_finish
resume_handle
resume_start
roundodd
roundsd_sse_41
safejson
scanformat
schubfach
setarrayvector
setboolfield
setfield
setnodevector
shrinkbuffers
shrinkbuffersfull
shrinkstack
shrinkstackprotected
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:485:shrinkstackprotected Source: VM/src/lgc.cpp (lgc.cpp:485-498, hand-ported)
singlematch
sort_func
sort_heap
sort_less
sort_rec
sort_siftheap
sort_swap
stack_init
Node: cxx:Function:Luau.VM:VM/src/lstate.cpp:28:stack_init Source: VM/src/lstate.cpp:28-48 (hand-ported)
start_capture
start_gc_cycle_metrics
str_byte
str_char
str_find
str_find_aux
str_format
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:966:str_format
str_gsub
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:831:str_gsub
str_len
str_lower
str_match
str_pack
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:1407:str_pack
str_packsize
str_rep
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:83:str_rep
str_reverse
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:47:str_reverse
str_split
str_sub
str_unpack
str_upper
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:71:str_upper
stringresizeprotected
sweepgcopage
tableresizeprotected
tag_error
tclear
tclone
tconcat
tcreate
tfind
tfreeze
tinsert
tisfrozen
tmove
tpack
traverseclass
traverseclosure
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:398:traverseclosure Source: VM/src/lgc.cpp (lgc.cpp:398-415, hand-ported)
traverseobject
traverseproto
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:372:traverseproto Source: VM/src/lgc.cpp (lgc.cpp:372-396, hand-ported)
traversestack
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:417:traversestack Source: VM/src/lgc.cpp (lgc.cpp:417-430, hand-ported)
traversetable
Node: cxx:Function:Luau.VM:VM/src/lgc.cpp:321:traversetable Source: VM/src/lgc.cpp (lgc.cpp:321-366, hand-ported)
tremove
trimzero
tsort
tunpack
u_posrelat
unlinkstr
unpackint
updateaboundary
utf_8_decode
utfchar
utflen
validateclass
validateclosure
validategco
validategraylist
validategraylist — validate every node in a GC gray list. C++ source: VM/src/lgcdebug.cpp:218
validateobj
validateobject
validateobjref
validateproto
Node: cxx:Function:Luau.VM:VM/src/lgcdebug.cpp:115:validateproto
validateref
validatestack
validatetable
vector_abs
vector_angle
vector_ceil
vector_clamp
vector_create
vector_cross
vector_dot
vector_floor
vector_index
vector_lerp
vector_magnitude
vector_max
vector_min
vector_normalize
vector_sign
vm_case_lvmexecute
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:319:vm_case Source: VM/src/lvmexecute.cpp:319 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_aa
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1361:vm_case Source: VM/src/lvmexecute.cpp:1361 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ab
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1494:vm_case Source: VM/src/lvmexecute.cpp:1494 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ac
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1627:vm_case Source: VM/src/lvmexecute.cpp:1627 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ad
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1660:vm_case Source: VM/src/lvmexecute.cpp:1660 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ae
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1693:vm_case Source: VM/src/lvmexecute.cpp:1693 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_af
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1726:vm_case Source: VM/src/lvmexecute.cpp:1726 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ag
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1759:vm_case Source: VM/src/lvmexecute.cpp:1759 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ah
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1805:vm_case Source: VM/src/lvmexecute.cpp:1805 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ai
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1851:vm_case Source: VM/src/lvmexecute.cpp:1851 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_aj
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1912:vm_case Source: VM/src/lvmexecute.cpp:1912 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ak
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1973:vm_case Source: VM/src/lvmexecute.cpp:1973 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_al
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2026:vm_case Source: VM/src/lvmexecute.cpp:2026 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_am
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2049:vm_case Source: VM/src/lvmexecute.cpp:2049 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_an
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2070:vm_case Source: VM/src/lvmexecute.cpp:2070 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ao
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2091:vm_case Source: VM/src/lvmexecute.cpp:2091 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ap
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2112:vm_case Source: VM/src/lvmexecute.cpp:2112 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_aq
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2158:vm_case Source: VM/src/lvmexecute.cpp:2158 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ar
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2204:vm_case Source: VM/src/lvmexecute.cpp:2204 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_as
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2256:vm_case Source: VM/src/lvmexecute.cpp:2256 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_at
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2279:vm_case Source: VM/src/lvmexecute.cpp:2279 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_au
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2306:vm_case Source: VM/src/lvmexecute.cpp:2306 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_av
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2317:vm_case Source: VM/src/lvmexecute.cpp:2317 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_aw
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2328:vm_case Source: VM/src/lvmexecute.cpp:2328 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ax
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2339:vm_case Source: VM/src/lvmexecute.cpp:2339 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ay
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2350:vm_case Source: VM/src/lvmexecute.cpp:2350 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_az
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2366:vm_case Source: VM/src/lvmexecute.cpp:2366 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_b
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:326:vm_case Source: VM/src/lvmexecute.cpp:326 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ba
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2377:vm_case Source: VM/src/lvmexecute.cpp:2377 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bb
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2420:vm_case Source: VM/src/lvmexecute.cpp:2420 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bc
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2458:vm_case Source: VM/src/lvmexecute.cpp:2458 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bd
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2472:vm_case Source: VM/src/lvmexecute.cpp:2472 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_be
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2485:vm_case Source: VM/src/lvmexecute.cpp:2485 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bf
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2522:vm_case Source: VM/src/lvmexecute.cpp:2522 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bg
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2546:vm_case Source: VM/src/lvmexecute.cpp:2546 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bh
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2573:vm_case Source: VM/src/lvmexecute.cpp:2573 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bi
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2695:vm_case Source: VM/src/lvmexecute.cpp:2695 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bj
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2807:vm_case Source: VM/src/lvmexecute.cpp:2807 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bk
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2830:vm_case Source: VM/src/lvmexecute.cpp:2830 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bl
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2853:vm_case Source: VM/src/lvmexecute.cpp:2853 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bm
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2873:vm_case Source: VM/src/lvmexecute.cpp:2873 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bn
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2902:vm_case Source: VM/src/lvmexecute.cpp:2902 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bo
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2959:vm_case Source: VM/src/lvmexecute.cpp:2959 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bp
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2988:vm_case Source: VM/src/lvmexecute.cpp:2988 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bq
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:2998:vm_case Source: VM/src/lvmexecute.cpp:2998 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_br
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3009:vm_case Source: VM/src/lvmexecute.cpp:3009 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bs
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3019:vm_case Source: VM/src/lvmexecute.cpp:3019 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bt
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3068:vm_case Source: VM/src/lvmexecute.cpp:3068 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bu
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3080:vm_case Source: VM/src/lvmexecute.cpp:3080 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bv
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3086:vm_case Source: VM/src/lvmexecute.cpp:3086 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bw
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3107:vm_case Source: VM/src/lvmexecute.cpp:3107 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bx
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3135:vm_case Source: VM/src/lvmexecute.cpp:3135 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_by
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3183:vm_case Source: VM/src/lvmexecute.cpp:3183 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_bz
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3233:vm_case Source: VM/src/lvmexecute.cpp:3233 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_c
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:335:vm_case Source: VM/src/lvmexecute.cpp:335 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ca
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3283:vm_case Source: VM/src/lvmexecute.cpp:3283 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cb
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3340:vm_case Source: VM/src/lvmexecute.cpp:3340 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cc
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3359:vm_case Source: VM/src/lvmexecute.cpp:3359 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cd
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3372:vm_case Source: VM/src/lvmexecute.cpp:3372 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ce
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3383:vm_case Source: VM/src/lvmexecute.cpp:3383 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cf
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3405:vm_case Source: VM/src/lvmexecute.cpp:3405 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cg
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3418:vm_case Source: VM/src/lvmexecute.cpp:3418 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ch
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3498:vm_case Source: VM/src/lvmexecute.cpp:3498 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ci
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3573:vm_case Source: VM/src/lvmexecute.cpp:3573 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_cj
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3670:vm_case Source: VM/src/lvmexecute.cpp:3670 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_ck
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:3684:vm_case Source: VM/src/lvmexecute.cpp:3684 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_d
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:347:vm_case Source: VM/src/lvmexecute.cpp:347 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_e
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:356:vm_case Source: VM/src/lvmexecute.cpp:356 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_f
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:366:vm_case Source: VM/src/lvmexecute.cpp:366 (hand-ported as a match arm inside functions/luau_execute.rs — VM_CASE arms share the interpreter locals and are not standalone functions; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_g
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:376:vm_case Source: VM/src/lvmexecute.cpp:376 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_h
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:407:vm_case Source: VM/src/lvmexecute.cpp:407 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_i
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:439:vm_case Source: VM/src/lvmexecute.cpp:439 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_j
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:450:vm_case Source: VM/src/lvmexecute.cpp:450 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_k
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:462:vm_case Source: VM/src/lvmexecute.cpp:462 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_l
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:472:vm_case Source: VM/src/lvmexecute.cpp:472 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_m
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:494:vm_case Source: VM/src/lvmexecute.cpp:494 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_n
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:665:vm_case Source: VM/src/lvmexecute.cpp:665 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_o
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:741:vm_case Source: VM/src/lvmexecute.cpp:741 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_p
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:771:vm_case Source: VM/src/lvmexecute.cpp:771 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_q
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:802:vm_case Source: VM/src/lvmexecute.cpp:802 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_r
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:830:vm_case Source: VM/src/lvmexecute.cpp:830 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_s
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:859:vm_case Source: VM/src/lvmexecute.cpp:859 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_t
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:902:vm_case Source: VM/src/lvmexecute.cpp:902 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_u
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1038:vm_case Source: VM/src/lvmexecute.cpp:1038 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_v
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1145:vm_case Source: VM/src/lvmexecute.cpp:1145 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_w
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1265:vm_case Source: VM/src/lvmexecute.cpp:1265 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_x
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1332:vm_case Source: VM/src/lvmexecute.cpp:1332 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_y
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1341:vm_case Source: VM/src/lvmexecute.cpp:1341 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
vm_case_lvmexecute_alt_z
Node: cxx:Function:Luau.VM:VM/src/lvmexecute.cpp:1351:vm_case Source: VM/src/lvmexecute.cpp:1351 (hand-ported as a match arm inside functions/luau_execute.rs; see translation/design-cards/lvmexecute.md)
writestring