Module lua_l_addvalueany

Module lua_l_addvalueany 

Node: cxx:Function:Luau.VM:VM/src/laux.cpp:529:luaL_addvalueany Source: VM/src/laux.cpp:529-582 (hand-ported)

Functions

lua_l_addvalueany
C++ void luaL_addvalueany(luaL_Strbuf *B, int idx) — converts the value at stack index idx to its string representation and appends it to buffer B.