pub fn lua_l_addvalueany(B: *mut LuaLStrbuf, idx: c_int)Expand description
C++ void luaL_addvalueany(luaL_Strbuf *B, int idx) —
converts the value at stack index idx to its string representation
and appends it to buffer B.
pub fn lua_l_addvalueany(B: *mut LuaLStrbuf, idx: c_int)C++ void luaL_addvalueany(luaL_Strbuf *B, int idx) —
converts the value at stack index idx to its string representation
and appends it to buffer B.