lua_setuserdatametatable — pop a table from the stack and register it as
the metatable for userdata of type tag.
C++ source: VM/src/lapi.cpp:1616
lua_setuserdatametatable — pop a table from the stack and register it as
the metatable for userdata of type tag.
C++ source: VM/src/lapi.cpp:1616