Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:47:str_reverse
string.reverse — copy the argument bytes into a fresh buffer back-to-front.
Node: cxx:Function:Luau.VM:VM/src/lstrlib.cpp:47:str_reverse
string.reverse — copy the argument bytes into a fresh buffer back-to-front.