Node: cxx:Function:Luau.VM:VM/src/laux.cpp:449:extendstrbuf
Grow a luaL_Strbuf past its inline buffer: allocate a GC string of the next
size, copy the used prefix, box it on the stack at boxloc (inserting a slot
the first time it spills off the inline buffer), and repoint p/end/storage.