#[repr(C)]pub struct LuaCallbacks {
pub userdata: *mut c_void,
pub interrupt: Option<unsafe extern "C-unwind" fn(l: *mut lua_State, gc: c_int)>,
pub panic: Option<unsafe extern "C" fn(l: *mut lua_State, errcode: c_int)>,
pub userthread: Option<unsafe extern "C" fn(lp: *mut lua_State, l: *mut lua_State)>,
pub useratom: Option<unsafe extern "C" fn(l: *mut lua_State, s: *const c_char, len: usize) -> i16>,
pub debugbreak: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>,
pub debugstep: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>,
pub debuginterrupt: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>,
pub debugprotectederror: Option<unsafe extern "C-unwind" fn(l: *mut lua_State)>,
pub onallocate: Option<unsafe extern "C" fn(l: *mut lua_State, osize: usize, nsize: usize)>,
}Fields
userdata: *mut c_voidarbitrary userdata pointer that is never overwritten by Luau
interrupt: Option<unsafe extern "C-unwind" fn(l: *mut lua_State, gc: c_int)>gets called at safepoints (loop back edges, call/ret, gc) if set
panic: Option<unsafe extern "C" fn(l: *mut lua_State, errcode: c_int)>gets called when an unprotected error is raised (if longjmp is used)
userthread: Option<unsafe extern "C" fn(lp: *mut lua_State, l: *mut lua_State)>gets called when L is created (LP == parent) or destroyed (LP == NULL)
useratom: Option<unsafe extern "C" fn(l: *mut lua_State, s: *const c_char, len: usize) -> i16>gets called when a string is created to assign an atom id
debugbreak: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>gets called when BREAK instruction is encountered
debugstep: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>gets called after each instruction in single step mode
debuginterrupt: Option<unsafe extern "C" fn(l: *mut lua_State, ar: *mut LuaDebug)>gets called when thread execution is interrupted by break in another thread
debugprotectederror: Option<unsafe extern "C-unwind" fn(l: *mut lua_State)>gets called when protected call results in an error
onallocate: Option<unsafe extern "C" fn(l: *mut lua_State, osize: usize, nsize: usize)>gets called when memory is allocated