pub struct LuauObject {
pub gclist: *mut GcObject,
pub lclass: *mut LuauClass,
pub numberofmembers: c_int,
pub members: *mut TValue,
/* private fields */
}Fields
gclist: *mut GcObjectlclass: *mut LuauClassThe class object that this value is an instance of.
numberofmembers: c_intThe number of members that this instance contains. We need this in order to free ourselves if we got swept in the same GC cycle as our class pointer.
members: *mut TValueThe fields of this instance.
Implementations
Sourceimpl LuauObject
impl LuauObject
pub const CommonHeader: () = ()